@@ -9,7 +9,7 @@ use Method::Signatures::Utils;
 use Method::Signatures::Parameter;
 use Method::Signatures::Signature;
 
-our $VERSION = '20151120.1519_001';
+our $VERSION = '20160310.2049_001';
 
 our $DEBUG = $ENV{METHOD_SIGNATURES_DEBUG} || 0;
 
@@ -26,6 +26,8 @@ sub my_hints() {
 
 Method::Signatures - method and function declarations with signatures and no source filter
 
+=for readme plugin version
+
 =head1 SYNOPSIS
 
     package Foo;
@@ -36,6 +38,8 @@ Method::Signatures - method and function declarations with signatures and no sou
         return bless {%args}, $self;
     }
 
+=for readme stop 
+
     method get ($key) {
         return $self->{$key};
     }
@@ -44,16 +48,21 @@ Method::Signatures - method and function declarations with signatures and no sou
         return $self->{$key} = $val;
     }
 
+=for readme start
+
     # Can also get type checking if you like:
 
     method set (Str $key, Int $val) {
         return $self->{$key} = $val;        # now you know $val is always an integer
     }
 
+=for readme stop
+
     func hello($greeting, $place) {
         print "$greeting, $place!\n";
     }
 
+=for readme start
 
 =head1 DESCRIPTION
 
@@ -69,6 +78,41 @@ C<method> is like C<func> but specifically for making methods.  It will
 automatically provide the invocant as C<$self> (L<by default|/invocant>).
 No more C<my $self = shift>.
 
+=begin :readme
+
+=head1 INSTALLATION 
+
+This module sources are hosted on github 
+https://github.com/evalEmpire/method-signatures.git 
+and uses C<Module::Build> to generate the distribution. It can be 
+istalled:
+
+=over 
+
+=item directly
+
+ cpanm git://github.com/evalEmpire/method-signatures.git
+
+=item from CPAN
+
+ cpan Method::Signatures
+ cpanm Method::Signatures
+
+=item maualy cloninig the repository:
+
+ git clone https://github.com/evalEmpire/method-signatures.git
+ cd method-signatures
+ perl Build.PL
+ ./Build install 
+
+=back
+ 
+=for readme plugin requires
+
+=end :readme
+
+=for readme stop
+
 Also allows signatures, very similar to Perl 6 signatures.
 
 Also does type checking, understanding all the types that Moose (or Mouse)
@@ -876,7 +920,7 @@ sub inject_from_signature {
 
     my $max_argv = $signature->max_argv_size;
     my $max_args = $signature->max_args;
-    push @code, qq[$class->too_many_args_error($max_args) if \@_ > $max_argv; ]
+    push @code, qq[$class->too_many_args_error($max_args) if scalar(\@_) > $max_argv; ]
         unless $max_argv == $INF;
 
     # Add any additional trailing newlines so the body is on the right line.
@@ -948,7 +992,7 @@ sub inject_for_sig {
         $sig->passed_in($rhs);
     }
 
-    my $check_exists = $sig->is_named ? "exists \$args{$name}" : "(\@_ > $idx)";
+    my $check_exists = $sig->is_named ? "exists \$args{$name}" : "( scalar(\@_) > $idx)";
     $sig->check_exists($check_exists);
 
     my $default = $sig->default;
@@ -1386,7 +1430,7 @@ strict error, perl might not notice until it tries to compile
 something else via an C<eval> or C<require> at which point perl will
 appear to fail where there is no reason to fail.
 
-We recommend you use the L<compile_at_BEGIN> flag to turn off
+We recommend you use the L<"compile_at_BEGIN"> flag to turn off
 compile-time parsing.
 
 You can't use any feature that requires a smartmatch expression (i.e.
